﻿-- ----------------------------------------------------------------------------
-- Grid2StatusIgnored by Potje
--       (Adapted from GridStatusIgnored written by Cyprias)
-- ----------------------------------------------------------------------------
local L = LibStub:GetLibrary("AceLocale-3.0"):GetLocale("Grid2")
local DBL = LibStub:GetLibrary("LibDBLayers-1.0")

local Grid2StatusIGNORED = Grid2:NewModule("StatusIgnored")
local IGNORED = Grid2.statusPrototype:new("ignored")
local ignoredNames = {}

Grid2 = Grid2

function IGNORED:UpdateAllUnits()
        ignoredNames = {} --reset, maybe they removed someone.
        local iName
        for i=1, GetNumIgnores() do
                iName = GetIgnoreName(i)
                if iName then
                        ignoredNames[iName] = true
                end
        end
end

function IGNORED:OnEnable()
        self:UpdateAllUnits()
        self:RegisterEvent("IGNORELIST_UPDATE", "UpdateAllUnits")
end

function IGNORED:OnDisable()
        self:UnregisterEvent("IGNORELIST_UPDATE")
end

function IGNORED:PlayerAndRealm(unitid)
        local name, realm = UnitName(unitid)
        if realm ~= nil and string.len(realm) > 0 then
                return name .. "-" .. realm
        end
        return name
end

function IGNORED:IsActive(unitid)
        local name = self:PlayerAndRealm(unitid)
        return ignoredNames[name];
end

function IGNORED:GetColor(unitid)
        local color = self.dbx.color1
        return color.r, color.g, color.b, color.a
end

function IGNORED:GetText(unitid)
        return L["Ignored"]
end

local function Create(baseKey, dbx)
        Grid2:RegisterStatus(IGNORED, {"color", "text"}, baseKey, dbx)
        return IGNORED
end

Grid2.setupFunc["ignored"] = Create

-- Hook the loading of options so our associated lod options get loaded at the right time.
local prev_LoadOptions = Grid2.LoadOptions

function Grid2:LoadOptions(dblData, ...)
        local upgrade = prev_LoadOptions(self, dblData, ...)

        upgrade = DBL:LoadOptions("Grid2StatusIgnoredOptions", dblData, nil, "account", 1) or upgrade

        return upgrade
end

-- Hook UpgradeDefaults to blend in default options if current ones are old.
local prev_UpgradeDefaults = Grid2.UpgradeDefaults
function Grid2:UpgradeDefaults(dblData, ...)
        local flatten = prev_UpgradeDefaults(self, dblData, ...)

        local Grid2StatusIgnoredOptions = Grid2Options.plugins["Grid2StatusIgnoredOptions"]
        if (Grid2StatusIgnoredOptions) then
                flatten = DBL:UpgradeDefaults("Grid2StatusIgnoredOptions", dblData, Grid2StatusIgnoredOptions.UpgradeDefaults, "account", 1) or flatten
        end

        return flatten
end

